unit TreeArchive;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  ComCtrls, StdCtrls, siis_api;

const
PLUGIN_ID=$0006;

type
  TArchiveDialog = class(TForm)
    PageControl1: TPageControl;
    TabMain: TTabSheet;
    TabReadMe: TTabSheet;
    GroupBoxFolderInfo: TGroupBox;
    lblNoPages: TLabel;
    lblKwd: TLabel;
    lblDesc: TLabel;
    lblDocCount: TLabel;
    edtKwd: TEdit;
    edtDesc: TEdit;
    GroupBoxPagesInfo: TGroupBox;
    lblFName: TLabel;
    lblLName: TLabel;
    lblPKwd: TLabel;
    lblPDesc: TLabel;
    lblComments: TLabel;
    edtFName: TEdit;
    edtLName: TEdit;
    edtPKwd: TEdit;
    edtPDesc: TEdit;
    txtComments: TMemo;
    TreeViewFolders: TTreeView;
    lbFiles: TListBox;
    btnSelFiles: TButton;
    lblSelFolder: TLabel;
    btnArchive: TButton;
    txtReadMe: TMemo;
    SelFilesDialog: TOpenDialog;
    btnClear: TButton;
    lblFolderDate: TLabel;
    procedure btnBuildTreeClick(Sender: TObject);
    procedure AddFolderToTree(parent:TTreeNode; fi:TFolderInfo);
    procedure TreeViewFoldersClick(Sender: TObject);
    procedure RefreshFoldersTree;
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
    procedure FormCreate(Sender: TObject);
    procedure btnSelFilesClick(Sender: TObject);
    procedure btnClearClick(Sender: TObject);
    procedure btnArchiveClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

{var
  TreeDialog: TTreeDialog; }

implementation

// include functions prototypes
// ============================
{$INCLUDE ..\common\siis_prototypes.inc}

{$R *.DFM}


procedure TArchiveDialog.btnBuildTreeClick(Sender: TObject);
begin
 RefreshFoldersTree;
end;

procedure TArchiveDialog.RefreshFoldersTree;
var
FolderCount:TFoldersCount;
FolderInfo:TFolderInfo;
name:array[0..1024] of char;
kwd:array[0..1024] of char;
desc:array[0..1024] of char;
szDate:array[0..32] of char;

i:Integer;
begin
 TreeViewFolders.Items.Clear;
 FolderCount.hParenTFolder:=0;
 FolderCount.PluginID:=PLUGIN_ID;
 ssxGetFoldersCount(@FolderCount);
 for i:=0 to Foldercount.iFoldersCount-1 do
  begin
   FolderInfo.iParentFolder:=0;
   FolderInfo.iPos:=i+1;
   Folderinfo.szName:=@name;
   Folderinfo.szDescription:=@desc;
   Folderinfo.szKeywords:=@kwd;
   FolderInfo.szDate:=@szDate;
   // =================================================================
   // VERY IMPORTANT
   // set iNF to 0, we don't care about custom fields at this point
   // =================================================================
   FolderInfo.iNF:=0;
   ssxGetFolderInfo(@FolderInfo);
   AddFolderToTree(nil, FolderInfo);
  end;
end;

procedure TArchiveDialog.AddFolderToTree(parent:TTreeNode; fi:TFolderInfo);
Var
FolderCount:TFoldersCount;
FolderInfo:TFolderInfo;
name:array[0..128] of char;
kwd:array[0..128] of char;
desc:array[0..128] of char;
szDate:array[0..32] of char;
i:Integer;
tn:TTreeNode;
begin
 tn := TreeViewFolders.Items.AddChild(parent, fi.szName);
 tn.Data:=Pointer(fi.iFolderID);

 FolderCount.hParenTFolder:=fi.iFolderID;
 ssxgetFoldersCount(@FolderCount);
 for i:=0 to FolderCount.iFoldersCount-1 do
  begin
   FolderInfo.iParentFolder:=fi.iFolderID;
   FolderCount.PluginID:=PLUGIN_ID;
   FolderInfo.iPos:=i+1;
   Folderinfo.szName:=@name;
   Folderinfo.szDescription:=@desc;
   Folderinfo.szKeywords:=@kwd;
   Folderinfo.szDate:=@szDate;

   // =================================================================
   // VERY IMPORTANT
   // set iNF to 0, we don't care about custom fields at this point
   // =================================================================
   FolderInfo.iNF:=0;
   ssxGetFolderInfo(@FolderInfo);
   AddFolderToTree(tn, FolderInfo);
  end;
end;

procedure TArchiveDialog.TreeViewFoldersClick(Sender: TObject);
var
tn:TTreeNode;
fi:TFolderInfo;
dc:TDocumentsCount;
name:array[0..128] of char;
kwd:array[0..128] of char;
desc:array[0..128] of char;
szDate:array[0..32] of char;
begin
tn := TreeViewFolders.Selected;
if tn=nil then exit;

fi.iFolderID := Integer(tn.Data);
fi.szName := @name;
fi.szDescription:= @desc;
fi.szKeywords := @kwd;
fi.szDate := @szDate;
// =================================================================
// VERY IMPORTANT
// set iNF to 0, we don't care about custom fields at this point
// =================================================================
fi.iNF:=0;

ssxGetFolderInfo2(@fi);
edtKwd.Text:= fi.szKeywords;
edtDesc.Text:= fi.szDescription;
dc.iParenTFolder:=Integer(tn.Data);
ssxGetDocumentsCount(@dc);
lblNoPages.Caption:= IntToStr(dc.iDocumentsCount);
lblFolderDate.Caption := fi.szDate;
end;

procedure TArchiveDialog.FormClose(Sender: TObject; var Action: TCloseAction);
begin
TreeViewFolders.Items.Clear;
Action := caFree;
end;

procedure TArchiveDialog.FormCreate(Sender: TObject);
begin
RefreshFoldersTree;
end;

procedure TArchiveDialog.btnSelFilesClick(Sender: TObject);
Var
I:Integer;
begin
if SelFilesDialog.Execute then
 begin
  for i:=0 to SelFilesDialog.Files.Count-1 do
   lbFiles.Items.Add(SelFilesDialog.Files[i]);
 end;
end;

procedure TArchiveDialog.btnClearClick(Sender: TObject);
begin
lbFiles.Clear;
end;

procedure TArchiveDialog.btnArchiveClick(Sender: TObject);
Var
tn:TTreeNode;
docInfo:TDocumentInfo;
txtBuf:array[0..4096] of char;
i:Integer;
begin
tn := TreeViewFolders.Selected;
if tn = nil then exit;
docInfo.iParentFolder:= Integer(tn.Data);

// you need to fill the following members only once
// ================================================
 // built-in fields
 docInfo.szDescription := PChar(edtPDesc.Text);
 docInfo.szKeywords := PChar(edtPKwd.Text);

 // custom fields
 // we have three fields added to the pages table
 // FName, LName, and Comments
 docInfo.iNF:=3;
 docInfo.szCFN[0] := 'FName';
 docInfo.szCFN[1] := 'LName';
 docInfo.szCFN[2] := 'Comments';

 docInfo.szCFV[0] := PChar(edtFName.Text);
 docInfo.szCFV[1] := PChar(edtLName.Text);
 // get the contents of the memo
 txtComments.GetTextBuf(txtBuf, 4095);
 docInfo.szCFV[2] := txtBuf;
// ================================================

// the structure is ready to call the ssxAppendDocument()
// start the hour glass cursor
 Screen.Cursor:=crHourGlass;
 for i:=0 to lbFiles.Items.Count-1 do
 begin
  docInfo.szDocumentPath:=PChar(lbFiles.Items[i]);
  docInfo.szName := PChar(ExtractFileName(lbFiles.Items[i]));
  ssxAppendDocument(@DocInfo);
 end;
// end hour glass cursor
 Screen.Cursor:=crDefault;
end;

end.
